from setuptools import setup

setup(name='st_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['st_distributions'],
      author='Yifei Tong',
      author_email='tongyf.shane2013@outlook.com',
      zip_safe=False)
